==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective.md <==
# AwsBackupRecoveryPointObjective


```text
aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective
```

```text
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')
```



| Illustration | AwsBackupRecoveryPointObjective | AwsBackupRecoveryPointObjectiveCard | AwsBackupRecoveryPointObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective.png) | ![illustration for AwsBackupRecoveryPointObjective](../../../aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveCard](../../../aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveGroup](../../../aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjectiveGroup.Local.png) |




## AwsBackupRecoveryPointObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

## AwsBackupRecoveryPointObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryPointObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-q2-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective.md <==
# AwsBackupRecoveryPointObjective


```text
aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective
```

```text
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')
```



| Illustration | AwsBackupRecoveryPointObjective | AwsBackupRecoveryPointObjectiveCard | AwsBackupRecoveryPointObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective.png) | ![illustration for AwsBackupRecoveryPointObjective](../../../aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveCard](../../../aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveGroup](../../../aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjectiveGroup.Local.png) |




## AwsBackupRecoveryPointObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label', 'an optional description')
@enduml
```

## AwsBackupRecoveryPointObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryPointObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-q1-2022/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
